@@ -2,13 +2,9 @@
 # this repository contains the full copyright notices and license terms.
 
 from trytond.pool import Pool
-from . import sale
-from . import product
-from . import stock
-from . import configuration
-from . import invoice
-from . import party
-from . import sale_reporting
+
+from . import (
+    configuration, invoice, party, product, sale, sale_reporting, stock)
 
 
 def register():
@@ -21,9 +17,13 @@ def register():
         sale.SaleLineTax,
         sale.SaleLineIgnoredMove,
         sale.SaleLineRecreatedMove,
+        party.Party,
+        party.PartyCustomerCurrency,
+        party.PartySaleMethod,
         product.Configuration,
         product.DefaultLeadTime,
         product.Template,
+        product.ProductLeadTime,
         product.Product,
         product.SaleContext,
         stock.ShipmentOut,
@@ -35,18 +35,24 @@ def register():
         configuration.ConfigurationSequence,
         configuration.ConfigurationSaleMethod,
         sale_reporting.Context,
+        sale_reporting.Main,
+        sale_reporting.MainTimeseries,
         sale_reporting.Customer,
         sale_reporting.CustomerTimeseries,
+        sale_reporting.CustomerCategory,
+        sale_reporting.CustomerCategoryTimeseries,
+        sale_reporting.CustomerCategoryTree,
         sale_reporting.Product,
         sale_reporting.ProductTimeseries,
-        sale_reporting.Category,
-        sale_reporting.CategoryTimeseries,
-        sale_reporting.CategoryTree,
+        sale_reporting.ProductCategory,
+        sale_reporting.ProductCategoryTimeseries,
+        sale_reporting.ProductCategoryTree,
+        sale_reporting.RegionTree,
         sale_reporting.Country,
         sale_reporting.CountryTimeseries,
         sale_reporting.Subdivision,
         sale_reporting.SubdivisionTimeseries,
-        sale_reporting.Region,
+        sale_reporting.CountryTree,
         invoice.Invoice,
         invoice.Line,
         module='sale', type_='model')
@@ -58,7 +64,8 @@ def register():
         sale.ModifyHeader,
         party.Replace,
         party.Erase,
-        sale_reporting.OpenRegion,
+        sale_reporting.OpenRegionTree,
+        sale_reporting.OpenCountryTree,
         module='sale', type_='wizard')
     Pool.register(
         sale.SaleReport,
