@@ -6,7 +6,8 @@ from trytond.i18n import gettext
 from trytond.model import Workflow, fields
 from trytond.model.exceptions import AccessError
 from trytond.pool import Pool, PoolMeta
-from trytond.transaction import Transaction
+from trytond.pyson import Eval
+from trytond.transaction import Transaction, without_check_access
 
 
 def process_sale(func):
@@ -14,11 +15,15 @@ def process_sale(func):
     def wrapper(cls, invoices):
         pool = Pool()
         Sale = pool.get('sale.sale')
-        with Transaction().set_context(_check_access=False):
+        transaction = Transaction()
+        context = transaction.context
+        with without_check_access():
             sales = set(s for i in cls.browse(invoices) for s in i.sales)
         func(cls, invoices)
         if sales:
-            Sale.__queue__.process(sales)
+            with transaction.set_context(
+                    queue_batch=context.get('queue_batch', True)):
+                Sale.__queue__.process(sales)
     return wrapper
 
 
@@ -56,17 +61,8 @@ class Invoice(metaclass=PoolMeta):
 
     @classmethod
     def search_sales(cls, name, clause):
-        return [('lines.origin.sale' + clause[0].lstrip(name),)
-            + tuple(clause[1:3]) + ('sale.line',) + tuple(clause[3:])]
-
-    @classmethod
-    def copy(cls, invoices, default=None):
-        if default is None:
-            default = {}
-        else:
-            default = default.copy()
-        default.setdefault('sales', None)
-        return super(Invoice, cls).copy(invoices, default=default)
+        return [('lines.origin.sale' + clause[0][len(name):],
+                *clause[1:3], 'sale.line', *clause[3:])]
 
     @classmethod
     @process_sale
@@ -103,6 +99,15 @@ class Invoice(metaclass=PoolMeta):
 class Line(metaclass=PoolMeta):
     __name__ = 'account.invoice.line'
 
+    @classmethod
+    def __setup__(cls):
+        super().__setup__()
+        if not cls.origin.domain:
+            cls.origin.domain = {}
+        cls.origin.domain['sale.line'] = [
+            ('type', '=', Eval('type')),
+            ]
+
     @fields.depends('origin')
     def on_change_with_product_uom_category(self, name=None):
         pool = Pool()
@@ -113,9 +118,19 @@ class Line(metaclass=PoolMeta):
         # Use getattr as reference field can have negative id
         if (isinstance(self.origin, SaleLine)
                 and getattr(self.origin, 'unit', None)):
-            category = self.origin.unit.category.id
+            category = self.origin.unit.category
         return category
 
+    def get_warehouse(self, name):
+        pool = Pool()
+        SaleLine = pool.get('sale.line')
+        warehouse = super().get_warehouse(name)
+        if (not warehouse
+                and isinstance(self.origin, SaleLine)
+                and self.origin.warehouse):
+            warehouse = self.origin.warehouse.id
+        return warehouse
+
     @property
     def origin_name(self):
         pool = Pool()
@@ -135,10 +150,14 @@ class Line(metaclass=PoolMeta):
     def delete(cls, lines):
         pool = Pool()
         Sale = pool.get('sale.sale')
-        with Transaction().set_context(_check_access=False):
+        transaction = Transaction()
+        context = transaction.context
+        with without_check_access():
             invoices = (l.invoice for l in cls.browse(lines)
                 if l.type == 'line' and l.invoice)
             sales = set(s for i in invoices for s in i.sales)
         super().delete(lines)
         if sales:
-            Sale.__queue__.process(sales)
+            with transaction.set_context(
+                    queue_batch=context.get('queue_batch', True)):
+                Sale.__queue__.process(sales)
