@@ -177,10 +177,14 @@ class Sale(
             'readonly': ((Eval('state') != 'draft')
                 | (Eval('lines', [0]) & Eval('currency', 0))),
             })
-    lines = fields.One2Many('sale.line', 'sale', 'Lines', states={
-            'readonly': Eval('state') != 'draft',
-            },
-        depends={'party'})
+    lines = fields.One2Many(
+        'sale.line', 'sale', "Lines",
+        states={
+            'readonly': (
+                (Eval('state') != 'draft')
+                | ~Eval('company')
+                | ~Eval('currency')),
+            })
     comment = fields.Text('Comment')
     untaxed_amount = fields.Function(Monetary(
             "Untaxed", digits='currency', currency='currency'), 'get_amount')
@@ -1865,6 +1869,9 @@ class SaleLine(TaxableMixin, sequence_ordered(), ModelSQL, ModelView):
         if move.on_change_with_unit_price_required():
             move.unit_price = self.unit_price
             move.currency = self.sale.currency
+        else:
+            move.unit_price = None
+            move.currency = None
         move.planned_date = self.planned_shipping_date
         move.invoice_lines = self._get_move_invoice_lines(shipment_type)
         move.origin = self
